==> qtjambi-xml-5.15.5-sources.jar: io/qt/xml/QXmlAttributes.java <==
package io.qt.xml;


/**
 * <p>XML attributes</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlattributes.html">QXmlAttributes</a></p>
 */
public class QXmlAttributes extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#QXmlAttributes">QXmlAttributes::QXmlAttributes()</a></p>
     */
    @Deprecated
    public QXmlAttributes(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    @Deprecated
    private native static void initialize_native(QXmlAttributes instance);
    
    public QXmlAttributes(io.qt.xml.QXmlAttributes arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QXmlAttributes instance, io.qt.xml.QXmlAttributes arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#append">QXmlAttributes::append(QString,QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void append(java.lang.String qName, java.lang.String uri, java.lang.String localPart, java.lang.String value){
        append_native_cref_QString_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), qName, uri, localPart, value);
    }
    
    @io.qt.QtUninvokable
    private native void append_native_cref_QString_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String qName, java.lang.String uri, java.lang.String localPart, java.lang.String value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#clear">QXmlAttributes::clear()</a></p>
     */
    @io.qt.QtUninvokable
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clear_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#count">QXmlAttributes::count()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#index">QXmlAttributes::index(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final int index(java.lang.String qName){
        return index_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), qName);
    }
    
    @io.qt.QtUninvokable
    private native int index_native_cref_QString_constfct(long __this__nativeId, java.lang.String qName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#index-2">QXmlAttributes::index(QString,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final int index(java.lang.String uri, java.lang.String localPart){
        return index_native_cref_QString_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), uri, localPart);
    }
    
    @io.qt.QtUninvokable
    private native int index_native_cref_QString_cref_QString_constfct(long __this__nativeId, java.lang.String uri, java.lang.String localPart);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#length">QXmlAttributes::length()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int length(){
        return length_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int length_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#localName">QXmlAttributes::localName(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String localName(int index){
        return localName_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String localName_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#qName">QXmlAttributes::qName(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String qName(int index){
        return qName_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String qName_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#swap">QXmlAttributes::swap(QXmlAttributes&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void swap(io.qt.xml.QXmlAttributes other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QXmlAttributes(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QXmlAttributes(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#type-1">QXmlAttributes::type(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String type(java.lang.String qName){
        return type_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), qName);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String type_native_cref_QString_constfct(long __this__nativeId, java.lang.String qName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#type-2">QXmlAttributes::type(QString,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String type(java.lang.String uri, java.lang.String localName){
        return type_native_cref_QString_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), uri, localName);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String type_native_cref_QString_cref_QString_constfct(long __this__nativeId, java.lang.String uri, java.lang.String localName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#type">QXmlAttributes::type(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String type(int index){
        return type_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String type_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#uri">QXmlAttributes::uri(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String uri(int index){
        return uri_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String uri_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#value-1">QXmlAttributes::value(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String value(java.lang.String qName){
        return value_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), qName);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String value_native_cref_QString_constfct(long __this__nativeId, java.lang.String qName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#value-3">QXmlAttributes::value(QString,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String value(java.lang.String uri, java.lang.String localName){
        return value_native_cref_QString_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), uri, localName);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String value_native_cref_QString_cref_QString_constfct(long __this__nativeId, java.lang.String uri, java.lang.String localName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#value">QXmlAttributes::value(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String value(int index){
        return value_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String value_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlAttributes(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QXmlAttributes clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QXmlAttributes clone_native(long __this_nativeId);
}

==> qtjambi-xml-5.15.8-sources.jar: io/qt/xml/QXmlAttributes.java <==
package io.qt.xml;


/**
 * <p>XML attributes</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlattributes.html">QXmlAttributes</a></p>
 */
public class QXmlAttributes extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#QXmlAttributes">QXmlAttributes::QXmlAttributes()</a></p>
     */
    @Deprecated
    public QXmlAttributes(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    @Deprecated
    private native static void initialize_native(QXmlAttributes instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#QXmlAttributes">QXmlAttributes::QXmlAttributes(QXmlAttributes)</a></p>
     */
    public QXmlAttributes(io.qt.xml.QXmlAttributes arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QXmlAttributes instance, io.qt.xml.QXmlAttributes arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#append">QXmlAttributes::append(QString,QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void append(java.lang.String qName, java.lang.String uri, java.lang.String localPart, java.lang.String value){
        append_native_cref_QString_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), qName, uri, localPart, value);
    }
    
    @io.qt.QtUninvokable
    private native void append_native_cref_QString_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String qName, java.lang.String uri, java.lang.String localPart, java.lang.String value);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#clear">QXmlAttributes::clear()</a></p>
     */
    @io.qt.QtUninvokable
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clear_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#count">QXmlAttributes::count()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#index">QXmlAttributes::index(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final int index(java.lang.String qName){
        return index_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), qName);
    }
    
    @io.qt.QtUninvokable
    private native int index_native_cref_QString_constfct(long __this__nativeId, java.lang.String qName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#index-2">QXmlAttributes::index(QString,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final int index(java.lang.String uri, java.lang.String localPart){
        return index_native_cref_QString_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), uri, localPart);
    }
    
    @io.qt.QtUninvokable
    private native int index_native_cref_QString_cref_QString_constfct(long __this__nativeId, java.lang.String uri, java.lang.String localPart);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#length">QXmlAttributes::length()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int length(){
        return length_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int length_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#localName">QXmlAttributes::localName(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String localName(int index){
        return localName_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String localName_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#qName">QXmlAttributes::qName(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String qName(int index){
        return qName_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String qName_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#swap">QXmlAttributes::swap(QXmlAttributes&amp;)</a></p>
     */
    @io.qt.QtUninvokable
    public final void swap(io.qt.xml.QXmlAttributes other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QXmlAttributes(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void swap_native_ref_QXmlAttributes(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#type-1">QXmlAttributes::type(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String type(java.lang.String qName){
        return type_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), qName);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String type_native_cref_QString_constfct(long __this__nativeId, java.lang.String qName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#type-2">QXmlAttributes::type(QString,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String type(java.lang.String uri, java.lang.String localName){
        return type_native_cref_QString_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), uri, localName);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String type_native_cref_QString_cref_QString_constfct(long __this__nativeId, java.lang.String uri, java.lang.String localName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#type">QXmlAttributes::type(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String type(int index){
        return type_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String type_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#uri">QXmlAttributes::uri(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String uri(int index){
        return uri_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String uri_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#value-1">QXmlAttributes::value(QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String value(java.lang.String qName){
        return value_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), qName);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String value_native_cref_QString_constfct(long __this__nativeId, java.lang.String qName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#value-3">QXmlAttributes::value(QString,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String value(java.lang.String uri, java.lang.String localName){
        return value_native_cref_QString_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), uri, localName);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String value_native_cref_QString_cref_QString_constfct(long __this__nativeId, java.lang.String uri, java.lang.String localName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlattributes.html#value">QXmlAttributes::value(int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String value(int index){
        return value_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String value_native_int_constfct(long __this__nativeId, int index);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlAttributes(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QXmlAttributes clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QXmlAttributes clone_native(long __this_nativeId);
}
